@@ -1,29 +1,28 @@
 """Tests the funky.utils.log utilities."""
 
-import getpass
 import logging
 import os
-import mock
+from pathlib import Path
 
 import pytest
 
-import funky.utils.log as log
+from funky.utils import log
 
 
-@pytest.mark.parametrize('debug', [False, True])
-def test_init_logger(debug):
+@pytest.mark.parametrize("debug", [False, True])
+def test_init_logger(debug: bool) -> None:
     """Tests that loggers are initialized properly."""
     log.init_logger(debug=debug)
     assert log.logger.isEnabledFor(logging.DEBUG) == debug
 
 
-def test_logfile():
+def test_logfile(xdg_data_home: Path) -> None:
     """Tests that the debugging logfile is working correctly."""
     log.init_logger(debug=True)
-    log.logger.debug('TEST')
-    logfile = '/home/{}/.local/share/funky/debug.log'.format(getpass.getuser())
+    log.logger.debug("TEST")
+    logfile = f"{xdg_data_home}/funky/debug.log"
     assert os.path.isfile(logfile)
-    with open(logfile, 'r') as f:
-        assert 'TEST' in f.read()
+    with open(logfile, "r") as f:
+        assert "TEST" in f.read()
 
     os.remove(logfile)
